==> nextcloud-12.0.3.zip: nextcloud/apps/dav/l10n/ko.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "달력",
    "Todos" : "할 일",
    "{actor} created calendar {calendar}" : "{actor} 님이 달력 {calendar}을(를) 생성함",
    "You created calendar {calendar}" : "달력 {calendar}을(를) 생성함",
    "{actor} deleted calendar {calendar}" : "{actor} 님이 달력 {calendar}을(를) 삭제함",
    "You deleted calendar {calendar}" : "달력 {calendar}을(를) 삭제함",
    "{actor} updated calendar {calendar}" : "{actor} 님이 달력 {calendar}을(를) 업데이트함",
    "You updated calendar {calendar}" : "달력 {calendar}을(를) 업데이트함",
    "{actor} shared calendar {calendar} with you" : "{actor} 님이 내게 달력 {calendar}을(를) 공유함",
    "You shared calendar {calendar} with {user}" : "{user} 님과 달력 {calendar}을(를) 공유함",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 님이 {user} 님과 달력 {calendar}을(를) 공유함",
    "{actor} unshared calendar {calendar} from you" : "{actor} 님이 달력 {calendar}의 공유를 중단함",
    "You unshared calendar {calendar} from {user}" : "{user} 님과 달력 {calendar}의 공유를 중단함",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} 님이 {user} 님과 {calendar} 달력의 공유를 중단함",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 님이 달력 {calendar}의 공유를 해제함",
    "You shared calendar {calendar} with group {group}" : "달력 {calendar}을(를) 그룹 {group}와(과) 공유함",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 님이 달력 {calendar}을(를) 그룹 {group}와(과) 공유함",
    "You unshared calendar {calendar} from group {group}" : "달력 {calendar}을(를) 그룹 {group}와(과) 공유하지 않음",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} 님이 달력 {calendar}을(를) 그룹 {group}와(과) 공유하지 않음",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 님이 행사 {event}을(를) 달력 {calendar}에 생성함",
    "You created event {event} in calendar {calendar}" : "행사 {event}을(를) 달력 {calendar}에 생성함",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 님이 행사 {event}을(를) 달력 {calendar}에서 삭제함",
    "You deleted event {event} from calendar {calendar}" : "행사 {event}을(를) 달력 {calendar}에서 삭제함",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 님이 달력 {calendar}의 행사 {event}을(를) 업데이트함",
    "You updated event {event} in calendar {calendar}" : "달력 {calendar}의 행사 {event}을(를) 업데이트함",
    "{actor} created todo {todo} in list {calendar}" : "{actor} 님이 목록 {calendar}에 할 일 {todo}을(를) 생성함",
    "You created todo {todo} in list {calendar}" : "목록 {calendar}에 할 일 {todo}을(를) 생성함",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} 님이 목록 {calendar}에서 할 일 {todo}을(를) 삭제함",
    "You deleted todo {todo} from list {calendar}" : "목록 {calendar}에서 할 일 {todo}을(를) 삭제함",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} 님이 목록 {calendar}의 할 일 {todo}을(를) 업데이트함",
    "You updated todo {todo} in list {calendar}" : "목록 {calendar}의 할 일 {todo}을(를) 업데이트함",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} 님이 목록 {calendar}의 할 일 {todo}을(를) 끝냄",
    "You solved todo {todo} in list {calendar}" : "목록 {calendar}의 할 일 {todo}을(를) 끝냄",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} 님이 목록 {calendar}의 할 일 {todo}을(를) 다시 염",
    "You reopened todo {todo} in list {calendar}" : "목록 {calendar}의 할 일 {todo}을(를) 다시 염",
    "A <strong>calendar</strong> was modified" : "<strong>달력</strong>이 수정됨",
    "A calendar <strong>event</strong> was modified" : "달력 <strong>행사</strong>가 수정됨",
    "A calendar <strong>todo</strong> was modified" : "달력의 <strong>할 일</strong>이 수정됨",
    "Contact birthdays" : "연락처에 등록된 생일",
    "Personal" : "개인",
    "Contacts" : "연락처",
    "Technical details" : "기술 정보",
    "Remote Address: %s" : "원격 주소: %s",
    "Request ID: %s" : "요청 ID: %s"
},
"nplurals=1; plural=0;");

==> nextcloud-15.0.3.zip: nextcloud/apps/dav/l10n/ko.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "달력",
    "Todos" : "할 일",
    "Personal" : "개인",
    "{actor} created calendar {calendar}" : "{actor} 님이 달력 {calendar}을(를) 생성함",
    "You created calendar {calendar}" : "달력 {calendar}을(를) 생성함",
    "{actor} deleted calendar {calendar}" : "{actor} 님이 달력 {calendar}을(를) 삭제함",
    "You deleted calendar {calendar}" : "달력 {calendar}을(를) 삭제함",
    "{actor} updated calendar {calendar}" : "{actor} 님이 달력 {calendar}을(를) 업데이트함",
    "You updated calendar {calendar}" : "달력 {calendar}을(를) 업데이트함",
    "You shared calendar {calendar} as public link" : "달력 {calendar}을(를) 공개 링크로 공유함",
    "You removed public link for calendar {calendar}" : "달력 {calendar}의 공개 링크를 삭제함",
    "{actor} shared calendar {calendar} with you" : "{actor} 님이 내게 달력 {calendar}을(를) 공유함",
    "You shared calendar {calendar} with {user}" : "{user} 님과 달력 {calendar}을(를) 공유함",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 님이 {user} 님과 달력 {calendar}을(를) 공유함",
    "{actor} unshared calendar {calendar} from you" : "{actor} 님이 달력 {calendar}의 공유를 중단함",
    "You unshared calendar {calendar} from {user}" : "{user} 님과 달력 {calendar}의 공유를 중단함",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} 님이 {user} 님과 {calendar} 달력의 공유를 중단함",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 님이 달력 {calendar}의 공유를 해제함",
    "You shared calendar {calendar} with group {group}" : "달력 {calendar}을(를) 그룹 {group}와(과) 공유함",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 님이 달력 {calendar}을(를) 그룹 {group}와(과) 공유함",
    "You unshared calendar {calendar} from group {group}" : "달력 {calendar}을(를) 그룹 {group}와(과) 공유하지 않음",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} 님이 달력 {calendar}을(를) 그룹 {group}와(과) 공유하지 않음",
    "{actor} created event {event} in calendar {calendar}" : "{actor} 님이 행사 {event}을(를) 달력 {calendar}에 생성함",
    "You created event {event} in calendar {calendar}" : "행사 {event}을(를) 달력 {calendar}에 생성함",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} 님이 행사 {event}을(를) 달력 {calendar}에서 삭제함",
    "You deleted event {event} from calendar {calendar}" : "행사 {event}을(를) 달력 {calendar}에서 삭제함",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} 님이 달력 {calendar}의 행사 {event}을(를) 업데이트함",
    "You updated event {event} in calendar {calendar}" : "달력 {calendar}의 행사 {event}을(를) 업데이트함",
    "{actor} created todo {todo} in list {calendar}" : "{actor} 님이 목록 {calendar}에 할 일 {todo}을(를) 생성함",
    "You created todo {todo} in list {calendar}" : "목록 {calendar}에 할 일 {todo}을(를) 생성함",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} 님이 목록 {calendar}에서 할 일 {todo}을(를) 삭제함",
    "You deleted todo {todo} from list {calendar}" : "목록 {calendar}에서 할 일 {todo}을(를) 삭제함",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} 님이 목록 {calendar}의 할 일 {todo}을(를) 업데이트함",
    "You updated todo {todo} in list {calendar}" : "목록 {calendar}의 할 일 {todo}을(를) 업데이트함",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} 님이 목록 {calendar}의 할 일 {todo}을(를) 끝냄",
    "You solved todo {todo} in list {calendar}" : "목록 {calendar}의 할 일 {todo}을(를) 끝냄",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} 님이 목록 {calendar}의 할 일 {todo}을(를) 다시 염",
    "You reopened todo {todo} in list {calendar}" : "목록 {calendar}의 할 일 {todo}을(를) 다시 염",
    "A <strong>calendar</strong> was modified" : "<strong>달력</strong>이 수정됨",
    "A calendar <strong>event</strong> was modified" : "달력 <strong>행사</strong>가 수정됨",
    "A calendar <strong>todo</strong> was modified" : "달력의 <strong>할 일</strong>이 수정됨",
    "Contact birthdays" : "연락처에 등록된 생일",
    "Invitation canceled" : "초대장 취소됨",
    "Hello %s," : "%s 님 안녕하세요,",
    "The meeting »%1$s« with %2$s was canceled." : "\"%1$s\" 행사(%2$s 님이 진행함)가 취소되었습니다.",
    "Invitation updated" : "초대장 업데이트됨",
    "The meeting »%1$s« with %2$s was updated." : "\"%1$s\" 행사(%2$s 님이 진행함)가 업데이트되었습니다.",
    "%1$s invited you to »%2$s«" : "%1$s 님이 \"%2$s\"에 초대함",
    "When:" : "일시:",
    "Where:" : "장소:",
    "Description:" : "설명:",
    "Link:" : "링크:",
    "Accept" : "수락",
    "Contacts" : "연락처",
    "Technical details" : "기술 정보",
    "Remote Address: %s" : "원격 주소: %s",
    "Request ID: %s" : "요청 ID: %s",
    "Are you accepting the invitation?" : "초대를 수락하시겠습니까?",
    "Tentative" : "예정됨",
    "Save" : "저장",
    "Send invitations to attendees" : "참석자에게 초대장 보내기",
    "Automatically generate a birthday calendar" : "자동으로 생일 달력 생성",
    "Birthday calendars will be generated by a background job." : "배경 작업으로 생일 달력을 생성합니다.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "생일 달력이 생성되는 데 시간이 걸릴 수도 있습니다.",
    "%s via %s" : "%s(%s 경유)",
    "The meeting »%s« with %s was canceled." : "\"%s\" 행사(%s 님이 진행함)가 취소되었습니다.",
    "The meeting »%s« with %s was updated." : "\"%s\" 행사(%s 님이 진행함)가 업데이트되었습니다.",
    "%s invited you to »%s«" : "%s 님이 \"%s\"에 초대함",
    "CalDAV server" : "CalDAV 서버",
    "Please make sure to properly set up the email settings above." : "이메일 설정이 올바른지 확인하십시오."
},
"nplurals=1; plural=0;");
